@@ -16,7 +16,7 @@ use AutoLoader qw(AUTOLOAD) ;
 our @ISA = qw(Exporter) ;
 our %EXPORT_TAGS = ('all' => [ qw() ]) ;
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } ) ;
-our @EXPORT = qw(AddRule AddRuleTo AddSubpbsRule AddSubpbsRules ReplaceRule ReplaceRuleTo RemoveRule BuildOk) ;
+our @EXPORT = qw(AddRule AddRuleTo AddSubpbsRule ReplaceRule ReplaceRuleTo RemoveRule BuildOk) ;
 our $VERSION = '0.09' ;
 
 use File::Basename ;
@@ -28,8 +28,7 @@ use PBS::Shell ;
 use PBS::PBSConfig ;
 use PBS::Output ;
 use PBS::Constants ;
-use PBS::Plugin ;
-use PBS::Rules::Creator ;
+use PBS::Plugin;
 
 use base qw(PBS::Attributes) ;
 
@@ -129,9 +128,7 @@ $file_name =~ s/'$// ;
 my $class = 'User' ;
 
 my @rule_definition = @_ ;
-
-my $pbs_config = GetPbsConfig($package) ;
-RunUniquePluginSub($pbs_config , 'AddRule', $file_name, $line, \@rule_definition) ;
+RunUniquePluginSub('AddRule', $file_name, $line, \@rule_definition) ;
 
 my $first_argument = shift @rule_definition ;
 my ($name, $rule_type) ;
@@ -185,9 +182,7 @@ unless('' eq ref $class)
 	}
 
 my @rule_definition = @_ ;
-
-my $pbs_config = GetPbsConfig($package) ;
-RunUniquePluginSub($pbs_config, 'AddRule', $file_name, $line, \@rule_definition) ;
+RunUniquePluginSub('AddRule', $file_name, $line, \@rule_definition) ;
 
 my $first_argument = shift @rule_definition;
 my ($name, $rule_type) ;
@@ -235,8 +230,7 @@ $file_name =~ s/'$// ;
 my $class = 'User' ;
 
 my @rule_definition = @_ ;
-my $pbs_config = GetPbsConfig($package) ;
-RunUniquePluginSub($pbs_config , 'AddRule', $file_name, $line, \@rule_definition) ;
+RunUniquePluginSub('AddRule', $file_name, $line, \@rule_definition) ;
 
 my $first_argument = shift @rule_definition ;
 
@@ -287,8 +281,7 @@ $file_name =~ s/'$// ;
 my $class = shift ;
 
 my @rule_definition = @_ ;
-my $pbs_config = GetPbsConfig($package) ;
-RunUniquePluginSub($pbs_config, 'AddRule', $file_name, $line, \@rule_definition) ;
+RunUniquePluginSub('AddRule', $file_name, $line, \@rule_definition) ;
 
 my $first_argument = shift @rule_definition ;
 my ($name, $rule_type) ;
@@ -356,14 +349,8 @@ if(exists $package_rules{$package}{$class})
 		}
 	}
 
-my %rule_type ;
-for my $rule_type (@$rule_types)
-	{
-	$rule_type{$rule_type}++
-	}
-
 #>>>>>>>>>>>>>
-# special handling for CREATOR  rules
+# special handling for CREATOR TYPED rules
 # if a rule is [CREATOR] and no creator was defined in the depender definition,
 # we put a creator in the depender definition and give the builder as argument to the creator
 
@@ -371,30 +358,33 @@ for my $rule_type (@$rule_types)
 # AddRule [CREATOR], [ 'a' =>' b'], 'touch %FILE_TO_BUILD' ;
 # and have the creator handle the digest part and call the builder to create the node
 
-if($rule_type{__CREATOR})
+for my $rule_type (@$rule_types)
 	{
-	if('ARRAY' eq ref $depender_definition)
+	if($rule_type eq CREATOR)
 		{
-		if('ARRAY' eq ref $depender_definition->[0])
+		if('ARRAY' eq ref $depender_definition)
 			{
-			die ERROR "[CREATOR] rules can't have a creator defined within depender!\n" ;
-			}
-			
-		if(defined $builder_definition)
-			{
-			#Let there be magic!
-			unshift @$depender_definition, [GenerateCreator($builder_definition)] ;
-			$builder_definition = undef ;
+			if('ARRAY' eq ref $depender_definition->[0])
+				{
+				die ERROR "[CREATOR] rules can't have a creator defined within depender!\n" ;
+				}
+				
+			if(defined $builder_definition)
+				{
+				#Let there be magic!
+				unshift @$depender_definition, [sub{ print 'hi'}, $builder_definition] ;
+				$builder_definition = undef ;
+				}
+			else
+				{
+				die ERROR "[CREATOR] rules must have a builder!\n" ;
+				}
 			}
 		else
 			{
-			die ERROR "[CREATOR] rules must have a builder!\n" ;
+			die ERROR "[CREATOR] rules must have depender in form ['object_to_create => dependencies]!\n" ;
 			}
 		}
-	else
-		{
-		die ERROR "[CREATOR] rules must have depender in form ['object_to_create => dependencies]!\n" ;
-		}
 	}
 #<<<<<<<<<<<<<<<<<<<<<<
 
@@ -405,30 +395,25 @@ my ($depender_sub, $node_subs2, $depender_generated_types) = GenerateDepender($f
 $depender_generated_types  ||= [] ; 
 
 my $origin = '' ;
-$origin = ":$package:$class:$file_name:$line"  if($pbs_config->{ADD_ORIGIN}) ;
+if($pbs_config->{ADD_ORIGIN})
+	{
+	$origin = ":$package:$class:$file_name:$line" ;
+	}
 	
+my ($post_depend, $meta_slave, $creator) ;
+
+@$rule_types = keys %{{map({($_, 1)} (@$rule_types, @$depender_generated_types))}} ;
+
 for my $rule_type (@$rule_types)
 	{
-	$rule_type{$rule_type}++
-	}
-	
-if($rule_type{__VIRTUAL} && $rule_type{__LOCAL})
-	{
-	PrintError("Rule can't be 'VIRTUAL' and 'LOCAL'.") ;
-	PbsDisplayErrorWithContext($file_name,$line) ;
-	die ;
-	}
-	
-if($rule_type{__POST_DEPEND} && $rule_type{__CREATOR})
-	{
-	PrintError("Rule can't be 'POST_DEPEND' and 'CREATOR'.") ;
-	PbsDisplayErrorWithContext($file_name,$line) ;
-	die ;
+	$creator++     if $rule_type eq CREATOR ;
+	$meta_slave++  if $rule_type eq META_SLAVE ;
+	$post_depend++ if $rule_type eq POST_DEPEND ;
 	}
 
-if($rule_type{__VIRTUAL} && $rule_type{__CREATOR})
+if($post_depend && $creator)
 	{
-	PrintError("Rule can't be 'VIRTUAL' and 'CREATOR'.") ;
+	Carp::carp ERROR("Rule can't be 'POST_DEPEND' and define a creator.") ;
 	PbsDisplayErrorWithContext($file_name,$line) ;
 	die ;
 	}
@@ -485,9 +470,9 @@ $rule_definition->{NODE_SUBS} = $node_subs if @$node_subs ;
 if(defined $pbs_config->{DEBUG_DISPLAY_RULES})
 	{
 	my $class_info = "[$class" ;
-	$class_info .= ' (POST_DEPEND)' if $rule_type{POST_DEPEND} ;
-	$class_info .= ' (META_SLAVE)'  if $rule_type{META_SLAVE} ;
-	$class_info .= ' (CREATOR)'     if $rule_type{CREATOR};
+	$class_info .= ' (POST_DEPEND)' if $post_depend ;
+	$class_info .= ' (META_SLAVE)' if $meta_slave ;
+	$class_info .= ' (CREATOR)' if $creator ;
 	$class_info .= ']' ;
 		
 	if('HASH' eq ref $depender_definition)
@@ -585,40 +570,22 @@ return
 
 
 #-------------------------------------------------------------------------------
-sub AddSubpbsRules
-{
-my ($package, $file_name, $line) = caller() ;
-$file_name =~ s/^'// ;
-$file_name =~ s/'$// ;
-
-for(@_)
-	{
-	__AddSubpbsRule($package, $file_name, $line, $_) ;
-	}
-}
 
 sub AddSubpbsRule
 {
-my ($package, $file_name, $line) = caller() ;
-$file_name =~ s/^'// ;
-$file_name =~ s/'$// ;
-
-__AddSubpbsRule($package, $file_name, $line, \@_) ;
-}
-
-sub __AddSubpbsRule
-{
 # Syntactic sugar, this function can be called instead for 
 # AddRule .. { subpbs_definition}
 # the compulsory arguments come first, then one can pass 
 # key-value pairs as in a normal subpbs definition
 
-my ($package, $file_name, $line, $rule_definition) = @_ ;
+my ($package, $file_name, $line) = caller() ;
+$file_name =~ s/^'// ;
+$file_name =~ s/'$// ;
 
-my $pbs_config = GetPbsConfig($package) ;
+my $rule_definition = \@_ ;
 
 my ($rule_name, $node_regex, $Pbsfile, $pbs_package, @other_setup_data) 
-	= RunUniquePluginSub($pbs_config, 'AddSubpbsRule', $file_name, $line, $rule_definition) ;
+	= RunUniquePluginSub('AddSubpbsRule', $file_name, $line, $rule_definition) ;
 
 RegisterRule
 	(
@@ -645,7 +612,7 @@ RegisterRule
 __END__
 =head1 NAME
 
-PBS::Rules - Manipulate PBS rules
+PBS::Rules::Rules - Manipulate PBS rules
 
 =head1 SYNOPSIS
 
